@@ -40,12 +40,22 @@ extern crate paste;
 #[macro_use]
 extern crate rdftk_names;
 
+// ------------------------------------------------------------------------------------------------
+// Public Values
+// ------------------------------------------------------------------------------------------------
+
+///
+/// The name to report in errors in this representation.
+///
+pub const REPRESENTATION_NAME: &str = "RDF";
+
 // ------------------------------------------------------------------------------------------------
 // Modules
 // ------------------------------------------------------------------------------------------------
 
 pub mod urn;
 
+#[doc(hidden)]
 pub mod reader;
 
 pub mod writer;
