@@ -1,5 +1,6 @@
 use atelier_rdf::writer::model_to_rdf;
 use atelier_test::examples::motd::make_message_of_the_day_model;
+use rdftk_core::simple::graph_factory;
 use rdftk_io::turtle::writer::TurtleWriter;
 use rdftk_io::GraphWriter;
 
@@ -7,7 +8,7 @@ use rdftk_io::GraphWriter;
 fn test_smithy_to_rdf() {
     let model = make_message_of_the_day_model();
 
-    let result = model_to_rdf(&model.model, None);
+    let result = model_to_rdf(&model.model, None, graph_factory());
     assert!(result.is_ok());
     let rdf = result.unwrap();
 
